@@ -47,7 +47,7 @@ sub insert{
 
    # Check for whitespace
    if($dw->cget(-nospace) == 1){
-      if($str =~ /^\*$/){
+      if($str =~ /^\s*$/){
          $dw->bell;
          return;
       }
@@ -460,4 +460,4 @@ djberg96@hotmail.com
 
 Entry
 
-=cut
\ No newline at end of file
+=cut
